DatadogGqlLink class
DatadogGqlLink automatically creates RUM Resources, enables distributed
traces with first party hosts (specified in DatadogSdk.firstPartyHosts),
and automatically adds GraphQL attributes visible in both APM and RUM.
This link can be used on its own or with datadog_tracking_http_client.
This Link is not a terminating link.
Constructors
- DatadogGqlLink(DatadogSdk datadogSdk, Uri uri, {DatadogGqlListener? listener, bool trackPayload = false})
Properties
- datadogSdk → DatadogSdk
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- listener → DatadogGqlListener?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trackPayload → bool
-
When
true, the full GraphQL document (query or mutation string) is captured in the RUM resource eventfinal - uri → Uri
-
final
Methods
-
concat(
Link next) → Link -
Adds
nextafter this linkinherited -
dispose(
) → Future< void> -
Can be called to clean up resources
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
request(
Request request, [NextLink? forward]) → Stream< Response> -
A function called when a request reaches this
Link -
route(
LinkRouter route) → Link -
Route requests after this link
inherited
-
split(
bool test(Request request), Link left, [Link right = const PassthroughLink()]) → Link -
Split requests after this link
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited